@@ -191,11 +191,11 @@ class RBFNN(BaseEstimator, ClassifierMixin):
         # print(yh.shape)
         return yh
 
-class RBFNNClassifer(RBFNN):
+class RBFNNClassifier(RBFNN):
 
     def isRBFNN(self):
         return True
-        
+
     def __init__(self, n_hidden_nodes = 20):
 
         # invoking the __init__ of the parent class
